@@ -4,6 +4,7 @@ import requests
 import logging
 import fnmatch
 import datetime
+import pkg_resources
 
 from pathlib import Path
 from shutil import copyfileobj, copy
@@ -33,12 +34,17 @@ def download_file(url=None, filename=None, headers = {}, username=None, password
     # check if the file exists, and if so, set the last modification time in the header
     # this allows you to avoid re-downloading files that haven't changed
     if os.path.exists(filename):
-        headers = {'If-Modified-Since': (datetime.datetime.utcfromtimestamp(os.path.getmtime(filename))).strftime('%a, %d %b %Y %H:%M:%S GMT')}
+        headers['If-Modified-Since'] = (datetime.datetime.utcfromtimestamp(os.path.getmtime(filename))).strftime('%a, %d %b %Y %H:%M:%S GMT')
 
     with warnings.catch_warnings():
         warnings.simplefilter("ignore", category=ResourceWarning)
         fsrc = session.get(url, stream=True, verify=verify, headers=headers)
 
+
+    # need to delete the If-Modified-Since header so it's not set in the dictionary in subsequent calls
+    if headers.get('If-Modified-Since') != None:
+        del headers['If-Modified-Since']
+
     # the file hasn't changed
     if fsrc.status_code == 304:
         logging.info('File is current: ' + filename)
@@ -108,6 +114,13 @@ def download(remote_path='', remote_file='', local_path='', local_file='', heade
     if username != None:
         session.auth = (username, password)
 
+    if headers.get('User-Agent') == None:
+        try:
+            release_version = pkg_resources.get_distribution("pyspedas").version
+        except pkg_resources.DistributionNotFound:
+            release_version = 'bleeding edge'
+        headers['User-Agent'] = 'pySPEDAS ' + release_version
+
     out = []
     index_table={}
 
